@@ -71,18 +71,15 @@ colorval_name (gint colorval)
 	return "unknown";
 }
 
-GnibblesProperties *
-gnibbles_properties_new ()
+void
+gnibbles_properties_update (GnibblesProperties * tmp)
 {
-	GnibblesProperties *tmp;
 	gint i;
 	gchar buffer[256];
 	gchar *color_name;
 
 	conf_client = gconf_client_get_default ();
 
-	tmp = (GnibblesProperties *) g_malloc (sizeof (GnibblesProperties));
-
 	tmp->numworms = gconf_client_get_int (conf_client,
 					      KEY_NUM_WORMS,
 					      NULL);
@@ -125,6 +122,18 @@ gnibbles_properties_new ()
 	if (tmp->tilesize > 30)
 		tmp->tilesize = 30;
 
+	tmp->width = gconf_client_get_int (conf_client,
+					      KEY_WIDTH,
+					      NULL);
+	if (tmp->width < 1 || tmp->width > 3200)
+		tmp->width = tmp->tilesize * BOARDWIDTH;
+
+	tmp->height = gconf_client_get_int (conf_client,
+					      KEY_HEIGHT,
+					      NULL);
+	if (tmp->height < 1 || tmp->height > 2400)
+		tmp->height = tmp->tilesize * BOARDHEIGHT;
+
 	for (i = 0; i < NUMWORMS; i++) {
 		tmp->wormprops[i] = (GnibblesWormProps *) g_malloc (sizeof
 								    (GnibblesWormProps));
@@ -176,7 +185,18 @@ gnibbles_properties_new ()
 			tmp->wormprops[i]->right = gdk_keyval_name (GDK_Right);
 	}
 
-	return (tmp);
+}
+
+GnibblesProperties *
+gnibbles_properties_new (void)
+{
+	GnibblesProperties *tmp;
+
+	tmp = (GnibblesProperties *) g_malloc (sizeof (GnibblesProperties));
+
+	gnibbles_properties_update (tmp);
+
+	return tmp;
 }
 
 void
@@ -205,6 +225,8 @@ gnibbles_properties_copy (GnibblesProperties *props)
 	tmp->startlevel = props->startlevel;
 	tmp->sound = props->sound;
 	tmp->tilesize = props->tilesize;
+	tmp->width = props->width;
+	tmp->height = props->height;
 	
 	for (i = 0; i < NUMWORMS; i++) {
 		tmp->wormprops[i] = (GnibblesWormProps *) g_malloc (sizeof
@@ -277,37 +299,16 @@ gnibbles_properties_set_worm_color (gint i, gint value)
 	gconf_client_set_string (conf_client, buffer, color_name, NULL);
 	g_free (buffer);
 }
+
 void
-gnibbles_properties_set_worm_up (gint i, gchar *value)
+gnibbles_properties_set_height (gint value)
 {
-	gchar *buffer;
-	buffer = g_strdup_printf (KEY_WORM_UP, i);
-	gconf_client_set_string (conf_client, buffer, value, NULL);
-	g_free (buffer);
+	gconf_client_set_int (conf_client, KEY_HEIGHT, value, NULL);
 }
 void
-gnibbles_properties_set_worm_down (gint i, gchar *value)
+gnibbles_properties_set_width (gint value)
 {
-	gchar *buffer;
-	buffer = g_strdup_printf (KEY_WORM_DOWN, i);
-	gconf_client_set_string (conf_client, buffer, value, NULL);
-	g_free (buffer);
-}
-void
-gnibbles_properties_set_worm_left (gint i, gchar *value)
-{
-	gchar *buffer;
-	buffer = g_strdup_printf (KEY_WORM_LEFT, i);
-	gconf_client_set_string (conf_client, buffer, value, NULL);
-	g_free (buffer);
-}
-void
-gnibbles_properties_set_worm_right (gint i, gchar *value)
-{
-	gchar *buffer;
-	buffer = g_strdup_printf (KEY_WORM_RIGHT, i);
-	gconf_client_set_string (conf_client, buffer, value, NULL);
-	g_free (buffer);
+	gconf_client_set_int (conf_client, KEY_WIDTH, value, NULL);
 }
 
 void
